Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/notifications.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJoas Schilling <coding@schilljs.com>2017-08-01 18:02:36 +0300
committerJoas Schilling <coding@schilljs.com>2017-08-02 11:25:59 +0300
commit00f3d2eb02bdfd6b2ee3973ef6621a02fcd54e9e (patch)
tree75e55b178535c0a882881851af47d23b914067a9 /js/notification.js
parent659c3ffff7fae8abbea4c6e16db1fd53a2ad2d8b (diff)
Allow to expand the message on click...
Signed-off-by: Joas Schilling <coding@schilljs.com>
Diffstat (limited to 'js/notification.js')
-rw-r--r--js/notification.js11
1 files changed, 6 insertions, 5 deletions
diff --git a/js/notification.js b/js/notification.js
index 3bc1eeb..933e374 100644
--- a/js/notification.js
+++ b/js/notification.js
@@ -81,14 +81,14 @@
var message = this.data.message;
/**
* Trim on word end after 100 chars or hard 120 chars
*/
- if (message.length > 120) {
- var spacePosition = message.indexOf(' ', 100);
- if (spacePosition !== -1 && spacePosition <= 120) {
+ if (message.length > 200) {
+ var spacePosition = message.indexOf(' ', 180);
+ if (spacePosition !== -1 && spacePosition <= 200) {
message = message.substring(0, spacePosition);
} else {
- message = message.substring(0, 120);
+ message = message.substring(0, 200);
}
message += '…';
}
@@ -125,6 +125,7 @@
subject: this.getSubject(),
link: this.getLink(),
message: this.getMessage(),
+ full_message: this.data.message,
timestamp: this.getTimestamp(),
relativeDate: OC.Util.relativeModifiedDate(this.getTimestamp()),
absoluteDate: OC.Util.formatDate(this.getTimestamp())
@@ -81,14 +81,14 @@
var message = this.data.message;
/**
- * Trim on word end after 100 chars or hard 120 chars
+ * Trim on word end after 180 chars or hard 200 chars
*/